// src/Callout.tsx
import * as React from "react";
import PropTypes from "prop-types";
import { Box, safelySpreadBoxProps } from "@twilio-paste/box";
import { ErrorIcon } from "@twilio-paste/icons/esm/ErrorIcon";
import { NeutralIcon } from "@twilio-paste/icons/esm/NeutralIcon";
import { NewIcon } from "@twilio-paste/icons/esm/NewIcon";
import { ScreenReaderOnly } from "@twilio-paste/screen-reader-only";
import { SuccessIcon } from "@twilio-paste/icons/esm/SuccessIcon";
import { WarningIcon } from "@twilio-paste/icons/esm/WarningIcon";
import { isMarginTokenProp } from "@twilio-paste/style-props";
var variantStyles = {
  success: {
    backgroundColor: "colorBackgroundSuccessWeakest",
    color: "colorTextSuccess",
    borderColor: "colorBorderSuccessWeaker"
  },
  error: {
    backgroundColor: "colorBackgroundErrorWeakest",
    color: "colorTextError",
    borderColor: "colorBorderErrorWeaker"
  },
  warning: {
    backgroundColor: "colorBackgroundWarningWeakest",
    color: "colorTextWarningStrong",
    borderColor: "colorBorderWarningWeaker"
  },
  new: {
    backgroundColor: "colorBackgroundNewWeakest",
    color: "colorTextNew",
    borderColor: "colorBorderNewWeaker"
  },
  neutral: {
    backgroundColor: "colorBackgroundNeutralWeakest",
    color: "colorTextNeutral",
    borderColor: "colorBorderNeutralWeaker"
  }
};
var variantIcons = {
  success: /* @__PURE__ */ React.createElement(SuccessIcon, { decorative: true, color: "colorTextIconSuccess" }),
  error: /* @__PURE__ */ React.createElement(ErrorIcon, { decorative: true, color: "colorTextIconError" }),
  warning: /* @__PURE__ */ React.createElement(WarningIcon, { decorative: true, color: "colorTextIconWarning" }),
  new: /* @__PURE__ */ React.createElement(NewIcon, { decorative: true, color: "colorTextIconNew" }),
  neutral: /* @__PURE__ */ React.createElement(NeutralIcon, { decorative: true, color: "colorTextIconNeutral" })
};
var defaultIconLabels = {
  success: "(success)",
  error: "(error)",
  warning: "(warning)",
  new: "(new)",
  neutral: "(information)"
};
var Callout = React.forwardRef(
  ({ children, variant, element = "CALLOUT", i18nLabel, marginY, ...props }, ref) => {
    const IconComponent = variantIcons[variant];
    const iconLabel = i18nLabel ? i18nLabel : defaultIconLabels[variant];
    return /* @__PURE__ */ React.createElement(
      Box,
      {
        ...safelySpreadBoxProps(props),
        ref,
        element,
        display: "flex",
        marginY,
        padding: "space60",
        borderStyle: "solid",
        borderWidth: "borderWidth10",
        borderRadius: "borderRadius30",
        variant,
        ...variantStyles[variant]
      },
      /* @__PURE__ */ React.createElement(Box, { marginRight: "space60", paddingTop: "space10", element: `${element}_ICON` }, IconComponent, /* @__PURE__ */ React.createElement(ScreenReaderOnly, null, iconLabel)),
      /* @__PURE__ */ React.createElement(Box, { display: "flex", flexDirection: "column", rowGap: "space50", flex: "1" }, children)
    );
  }
);
Callout.displayName = "Callout";
Callout.propTypes = {
  children: PropTypes.node,
  element: PropTypes.string,
  variant: PropTypes.oneOf(["neutral", "warning", "error", "success", "new", "default"]).isRequired,
  i18nLabel: PropTypes.string,
  marginY: isMarginTokenProp
};

// src/CalloutHeading.tsx
import * as React2 from "react";
import { Text, safelySpreadTextProps } from "@twilio-paste/text";
var CalloutHeading = React2.forwardRef(
  ({ element = "CALLOUT_HEADING", children, as = "h3", ...props }, ref) => /* @__PURE__ */ React2.createElement(
    Text,
    {
      ...safelySpreadTextProps(props),
      as,
      ref,
      element,
      color: "currentColor",
      lineHeight: "lineHeight40",
      fontWeight: "fontWeightSemibold"
    },
    children
  )
);
CalloutHeading.displayName = "CalloutHeading";

// src/CalloutList.tsx
import * as React3 from "react";
import PropTypes2 from "prop-types";
import { Box as Box2, safelySpreadBoxProps as safelySpreadBoxProps2 } from "@twilio-paste/box";
import { Text as Text2, safelySpreadTextProps as safelySpreadTextProps2 } from "@twilio-paste/text";
var CalloutList = React3.forwardRef(
  ({ element = "CALLOUT_LIST", children, as, ...props }, ref) => /* @__PURE__ */ React3.createElement(
    Box2,
    {
      ...safelySpreadBoxProps2(props),
      element,
      ref,
      as,
      margin: "space0",
      display: "flex",
      flexDirection: "column",
      rowGap: "space30",
      paddingLeft: "space60"
    },
    children
  )
);
CalloutList.displayName = "CalloutList";
CalloutList.propTypes = {
  children: PropTypes2.node,
  element: PropTypes2.string,
  as: PropTypes2.oneOf(["ul", "ol"]).isRequired
};
var CalloutListItem = React3.forwardRef(
  ({ element = "CALLOUT_LIST_ITEM", children, ...props }, ref) => /* @__PURE__ */ React3.createElement(Text2, { ...safelySpreadTextProps2(props), element, ref, as: "li", color: "currentColor" }, children)
);
CalloutListItem.displayName = "CalloutListItem";
CalloutListItem.propTypes = {
  children: PropTypes2.node,
  element: PropTypes2.string
};

// src/CalloutText.tsx
import * as React4 from "react";
import PropTypes3 from "prop-types";
import { Text as Text3, safelySpreadTextProps as safelySpreadTextProps3 } from "@twilio-paste/text";
var CalloutText = React4.forwardRef(
  ({ element = "CALLOUT_TEXT", children, ...props }, ref) => /* @__PURE__ */ React4.createElement(
    Text3,
    {
      ...safelySpreadTextProps3(props),
      as: "p",
      ref,
      element,
      color: "currentColor",
      lineHeight: "lineHeight40"
    },
    children
  )
);
CalloutText.displayName = "CalloutText";
CalloutText.propTypes = {
  children: PropTypes3.node,
  element: PropTypes3.string
};
export {
  Callout,
  CalloutHeading,
  CalloutList,
  CalloutListItem,
  CalloutText
};
